@@ -26,7 +26,6 @@ def generate_url(request):
     crypto = CryptoURL(THUMBOR_SECURITY_KEY)
     
     args = request.GET
-    # convert Django QueryDict to a python dict
     args = dict(zip(map(str, args.keys()), args.values()))
     error_message = None
 
@@ -56,7 +55,7 @@ def generate_url(request):
         return HttpResponseBadRequest(error_message)
 
     try:
-        return HttpResponse(THUMBOR_SERVER + crypto.generate(**args)[1:], mimetype="text/plain")
+        return HttpResponse(THUMBOR_SERVER + crypto.generate(**args).strip("/"), mimetype="text/plain")
     except (ValueError, KeyError), e:
         error_message = str(e)
         logging.warning(error_message)
